/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.user;

import cn.hutool.core.convert.Convert;
import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.post.Post;
import com.yiring.auth.domain.user.User;
import java.io.Serial;
import java.io.Serializable;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户导入
 *
 * @author LJ-2204
 * @date 2022/4/25
 */

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserImportExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = 3471291755743945051L;

    // 姓名
    @ExcelColumn(index = 0)
    String realName;

    // 工号
    @ExcelColumn(index = 1)
    String uuid;

    // 图标类型
    @ExcelColumn(index = 2)
    String type;

    // 手机号
    @ExcelColumn(index = 3)
    String mobile;

    // 部门id
    @ExcelColumn(index = 4)
    String deptId;

    // 职位id
    @ExcelColumn(index = 5)
    String postId;

    // 标签号
    @ExcelColumn(index = 6)
    String code;

    // 性别
    @ExcelColumn(index = 7)
    Boolean gender;

    // 是否为特殊人员
    @ExcelColumn(index = 8)
    Boolean isSpecial;

    public static User transform(UserImportExcel userImportExcel) {
        return User
            .builder()
            .realName(userImportExcel.getRealName())
            .uuid(userImportExcel.getUuid())
            .type(User.Type.valueOf(userImportExcel.getType()))
            .mobile(userImportExcel.getMobile())
            .department(Department.builder().id(Convert.toLong(userImportExcel.getDeptId())).build())
            .post(Post.builder().id(Convert.toLong(userImportExcel.getPostId())).build())
            .gender(userImportExcel.getGender())
            .isSpecial(userImportExcel.getIsSpecial())
            .build();
    }
}
